@@ -136,7 +136,7 @@ mcmcPlots = function(subjecti.u, subj.aff = NULL, subjaff.input = NULL, bmat.sum
    		l 				= geom_point()
    		f				= facet_wrap(~group,scales="free",ncol=2)
    		axis	 			= labs(x = "Session", y = "Effect Size", colour = "Group")
-   		options		 		= opts(title="Session Effects (u) - mm(CAR) Prior")
+   		options		 		= opts(title="Session Effects (u)")
    		p.U		 		= p.U + l + f + axis + options
 
 
@@ -152,7 +152,7 @@ mcmcPlots = function(subjecti.u, subj.aff = NULL, subjaff.input = NULL, bmat.sum
    		l.1 		= geom_line(colour = "steelblue4")
    		l.2		= geom_smooth(aes(group=1),method = "loess", span = .2, size = 1.2, colour = "pink")
    		axis 		= labs(x = "Subject", y = "Effect Size")
-   		options 	= opts(title="Session-induced client effects - CAR(mm(S))")
+   		options 	= opts(title="Session-induced client effects - mm = (W * u)")
    		p.Umm 		= p.Umm + l.1 + l.2 + axis + options 
 
 
@@ -168,7 +168,7 @@ mcmcPlots = function(subjecti.u, subj.aff = NULL, subjaff.input = NULL, bmat.sum
    		l.1 	= geom_line(colour = "steelblue4")
    		l.2	= geom_smooth(aes(group=1),method = "loess", span = .2, size = 1.2, colour = "pink")
    		axis 	= labs(x = "Subject", y = "Effect Size")
-   		options = opts(title="Session-induced client effects - CAR(mm(S) + b0)")
+   		options = opts(title="Session-induced client effects - mm0 + b0")
    		p.Ub0 	= p.Ub0 + l.1 + l.2 + axis + options 
 
 	
